#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# Copyright 2020 University of Liège
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


## Wake behind airfoil (around which the boundary layer is computed)
# Amaury Bilocq

from flow.viscous.boundary import Boundary
from flow.viscous.airfoil import Airfoil
import numpy as np

class Wake(Boundary):
    def __init__(self, _boundary):
        Boundary.__init__(self, _boundary)
        self.name = 'wake' # type of boundary
        self.T0 = 0 # initial condition for the momentum thickness
        self.H0 = 0
        self.n0 = 9 # wake is always turbulent
        self.Ct0 = 0


    def connectList(self):
        ''' Sort the value read by the viscous solver/ Create list of connectivity
        '''
        N1 = np.zeros(self.nN, dtype=int) # Node number
        connectListNodes = np.zeros(self.nN, dtype=int) # Index in boundary.nodes
        connectListElems = np.zeros(self.nE, dtype=int) # Index in boundary.elems
        data = np.zeros((self.boundary.nodes.size(), 10))
        i = 0
        for n in self.boundary.nodes:
            data[i,0] = n.no
            data[i,1] = n.pos[0]
            data[i,2] = n.pos[1]
            data[i,3] = n.pos[2]
            data[i,4] = self.v[i,0]
            data[i,5] = self.v[i,1]
            data[i,6] = self.Me[i]
            data[i,7] = self.rhoe[i]
            data[i,8] = self.deltaStar[i]
            data[i,9] = self.xx[i]
            i += 1
        # Table containing the element and its nodes
        eData = np.zeros((self.nE,3), dtype=int)
        for i in range(0, self.nE):
            eData[i,0] = self.boundary.tag.elems[i].no
            eData[i,1] = self.boundary.tag.elems[i].nodes[0].no
            eData[i,2] = self.boundary.tag.elems[i].nodes[1].no
        connectListNodes = data[:,1].argsort()
        connectListElems[0] = np.where(eData[:,1] == min(data[:,1]))[0]
        for i in range(1, len(eData[:,0])):
            connectListElems[i] = np.where(eData[:,1] == eData[connectListElems[i-1],2])[0]
        data[:,0] = data[connectListNodes,0]
        data[:,1] = data[connectListNodes,1]
        data[:,2] = data[connectListNodes,2]
        data[:,3] = data[connectListNodes,3]
        data[:,4] = data[connectListNodes,4]
        data[:,5] = data[connectListNodes,5]
        data[:,6] = data[connectListNodes,6]
        data[:,7] = data[connectListNodes,7]
        data[:,8] = data[connectListNodes,8]
        data[:,9] = data[connectListNodes,9]
        # Separated upper and lower part
        data = np.delete(data,0,1)
        return connectListNodes, connectListElems, data
