/*
 * Copyright 2020 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef WPROBLEM_H
#define WPROBLEM_H

#include "mirrors.h"
#include "wObject.h"
#include <iostream>
#include <vector>
#include <string>
#include <memory>

using namespace tbox;

namespace mirrors
{

/**
 * @brief a class containing the problem parameters
 */

class MIRRORS_API Problem : public fwk::wObject
{
public:
    std::shared_ptr<MshData> msh; ///< Mesh structure
#ifndef SWIG
    std::string problem_type;    // [RB] TODO use an enum instead!
    std::vector<Medium *> media; ///< Materials

    std::vector<uDirichlet *> duBCs; ///< mechanical Dirichlet boundary conditions
    std::vector<TDirichlet *> dTBCs; ///< thermal Dirichlet boundary conditions

    std::vector<TSource *> Tsrcs; ///< volumic heat sources

    std::vector<uNeumann *> nuBCs; ///< mechanical von Neumann boundary conditions
    std::vector<TNeumann *> nTBCs; ///< thermal von Neumann boundary conditions

    std::vector<MSurface *> MS; ///< Mirrors surface

    //std::vector<uContact*> uContact;     ///< mechanical contact interface
    //std::vector<TContact*> TContact;     ///< thermal contact interface

    double T_ref;
#endif
    double Sol;
    std::vector<ANSYSSolution *> ANSYSSol; ///< Ansys sol
public:
    Problem(std::shared_ptr<MshData> _msh, std::string problem_type, double T_ref = 0);

#ifndef SWIG
    void initElems();
    virtual void write(std::ostream &out) const override;
#endif
};

} // namespace mirrors

#endif //WPROBLEM_H
